#include "canvastest.h"

#include <QQmlEngine>

bool CanvasPrinter::save(const QString &fileName, const QString &fileFormat, int quality)
{
	return m_image.save(fileName, fileFormat.toStdString().c_str(), quality);
}

bool CanvasPrinter::setFromData(QVariantList data, int width, int height)
{
    if (data.isEmpty()) {
        return false;
    }

	uchar *raw = new uchar[ width * height * 4 ];

	int dslen = data.length();
	int ppos = 0;
	for( int z=0; z < dslen; )
	{
		uchar r = data.at(z++).toInt();
		uchar g = data.at(z++).toInt();
		uchar b = data.at(z++).toInt();
		uchar a = data.at(z++).toInt();

		raw[ ppos++ ] = r;
		raw[ ppos++ ] = g;
		raw[ ppos++ ] = b;
		raw[ ppos++ ] = a;
	}

	m_image = QImage( raw, width, height, QImage::Format_ARGB32, imageCleanupHandler, raw );
    return true;
}

void CanvasPrinter::clear()
{
	m_image = QImage();
}

void CanvasPrinter::imageCleanupHandler(void *info)
{
	delete (uchar*)info;
}

CanvasApp::CanvasApp(const QString &path) : QQuickView()
{
	qmlRegisterType<CanvasPrinter>("CanvasPrinter", 1, 0, "CanvasPrinter");

	QUrl mainQml = QUrl::fromLocalFile( path );
	setSource(mainQml);
}

int main(int argc, char **argv)
{
	QGuiApplication app(argc, argv);
	
	CanvasApp *a = new CanvasApp("canvastest.qml");
    QObject::connect(a->engine(), SIGNAL(quit()), a, SLOT(close()));
	a->show();

	return app.exec();
}

